@@ -3,12 +3,11 @@ bilibili_api.ass
 
 有关 ASS 文件的操作
 """
-
 import os
 from typing import Union
 
-from bilibili_api.bangumi import Episode
-from bilibili_api.cheese import CheeseVideo
+from .bangumi import Episode
+from .cheese import CheeseVideo
 from .exceptions.ArgsException import ArgsException
 
 from .utils.Credential import Credential
@@ -84,7 +83,7 @@ def export_ass_from_json(file_local, output_local) -> None:
 
 
 async def make_ass_file_subtitle(
-    obj: Union[Video, Episode], out = "test.ass", name = "中文（自动生成）"
+    obj: Union[Video, Episode], out="test.ass", name="中文（自动生成）"
 ) -> None:
     """
     生成视频字幕文件
@@ -94,11 +93,17 @@ async def make_ass_file_subtitle(
         out        (str, optional)       : 输出位置. Defaults to "test.ass".
         name       (str, optional)       : 字幕名，如”中文（自动生成）“,是简介的'subtitle'项的'list'项中的弹幕的'lan_doc'属性。Defaults to "中文（自动生成）".
     """
-    info = await obj.get_info()
-    json_files = info["subtitle"]["list"]
+    if isinstance(obj, Episode):
+        info = await obj.get_player_info(cid=await obj.get_cid(), epid=obj.get_epid())
+        json_files = info["subtitle"]["subtitles"]
+    else:
+        info = await obj.get_info() 
+        json_files = info["subtitle"]["list"]
     for subtitle in json_files:
         if subtitle["lan_doc"] == name:
             url = subtitle["subtitle_url"]
+            if isinstance(obj, Episode):
+                url = "https:" + url
             req = await get_session().request("GET", url)
             file_dir = gettempdir() + "/" + "subtitle.json"
             with open(file_dir, "wb") as f:
@@ -111,15 +116,15 @@ async def make_ass_file_subtitle(
 async def make_ass_file_danmakus_protobuf(
     obj: Union[Video, Episode, CheeseVideo],
     page: int = 0,
-    out = "test.ass",
+    out="test.ass",
     cid: Union[int, None] = None,
     credential: Union[Credential, None] = None,
-    date = None,
-    font_name = "Simsun",
-    font_size = 25.0,
-    alpha = 1,
-    fly_time = 7,
-    static_time = 5,
+    date=None,
+    font_name="Simsun",
+    font_size=25.0,
+    alpha=1,
+    fly_time=7,
+    static_time=5,
 ) -> None:
     """
     生成视频弹幕文件 *★,°*:.☆(￣▽￣)/$:*.°★* 。
@@ -150,18 +155,22 @@ async def make_ass_file_danmakus_protobuf(
             if cid is None:
                 if page is None:
                     raise ArgsException("page_index 和 cid 至少提供一个。")
-                cid = await v._Video__get_page_id_by_index(page) # type: ignore
+                cid = await v._Video__get_page_id_by_index(page)  # type: ignore
         try:
             info = await v.get_info()
         except:
             info = {"dimension": {"width": 1440, "height": 1080}}
         width = info["dimension"]["width"]
         height = info["dimension"]["height"]
+        if width == 0:
+            width = 1440
+        if height == 0:
+            height = 1080
         stage_size = (width, height)
         if isinstance(obj, Episode):
             danmakus = await v.get_danmakus()
         else:
-            danmakus = await v.get_danmakus(cid=cid, date=date) # type: ignore
+            danmakus = await v.get_danmakus(cid=cid, date=date)  # type: ignore
     elif isinstance(obj, CheeseVideo):
         stage_size = (1440, 1080)
         danmakus = await obj.get_danmakus()
@@ -187,13 +196,13 @@ async def make_ass_file_danmakus_protobuf(
 async def make_ass_file_danmakus_xml(
     obj: Union[Video, Episode, CheeseVideo],
     page: int = 0,
-    out = "test.ass",
+    out="test.ass",
     cid: Union[int, None] = None,
-    font_name = "Simsun",
-    font_size = 25.0,
-    alpha = 1,
-    fly_time = 7,
-    static_time = 5,
+    font_name="Simsun",
+    font_size=25.0,
+    alpha=1,
+    fly_time=7,
+    static_time=5,
 ) -> None:
     """
     生成视频弹幕文件 *★,°*:.☆(￣▽￣)/$:*.°★* 。
@@ -218,18 +227,22 @@ async def make_ass_file_danmakus_xml(
             if cid is None:
                 if page is None:
                     raise ArgsException("page_index 和 cid 至少提供一个。")
-                cid = await v._Video__get_page_id_by_index(page) # type: ignore
+                cid = await v._Video__get_page_id_by_index(page)  # type: ignore
         try:
             info = await v.get_info()
         except:
             info = {"dimension": {"width": 1440, "height": 1080}}
         width = info["dimension"]["width"]
         height = info["dimension"]["height"]
+        if width == 0:
+            width = 1440
+        if height == 0:
+            height = 1080
         stage_size = (width, height)
         if isinstance(obj, Episode):
             xml_content = await v.get_danmaku_xml()
         else:
-            xml_content = await v.get_danmaku_xml(cid=cid) # type: ignore
+            xml_content = await v.get_danmaku_xml(cid=cid)  # type: ignore
     elif isinstance(obj, CheeseVideo):
         stage_size = (1440, 1080)
         xml_content = await obj.get_danmaku_xml()
