@@ -45,7 +45,9 @@ def _geetest_urlhandler(url: str, content_type: str):
                 seccode = data[8:].replace("%7C", "|")
         with open(
             os.path.abspath(
-                os.path.join(os.path.dirname(__file__), "..", "data", "geetest", "done.html")
+                os.path.join(
+                    os.path.dirname(__file__), "..", "data", "geetest", "done.html"
+                )
             ),
             encoding="utf8",
         ) as f:
@@ -60,7 +62,9 @@ def _geetest_urlhandler(url: str, content_type: str):
         key = json_data["data"]["recaptcha_token"]
         with open(
             os.path.abspath(
-                os.path.join(os.path.dirname(__file__), "..", "data", "geetest", "captcha.html")
+                os.path.join(
+                    os.path.dirname(__file__), "..", "data", "geetest", "captcha.html"
+                )
             ),
             encoding="utf8",
         ) as f:
@@ -149,7 +153,7 @@ def _start_server(urlhandler, hostname, port):
             self.send_response(200)
             self.send_header("Content-Type", "%s; charset=UTF-8" % content_type)
             self.end_headers()
-            self.wfile.write(self.urlhandler(self.path, content_type).encode("utf-8")) # type: ignore
+            self.wfile.write(self.urlhandler(self.path, content_type).encode("utf-8"))  # type: ignore
 
         def log_message(self, *args):
             # Don't log messages.
@@ -160,7 +164,7 @@ def _start_server(urlhandler, hostname, port):
             self.host = host
             self.address = (self.host, port)
             self.callback = callback
-            self.base.__init__(self, self.address, self.handler) # type: ignore
+            self.base.__init__(self, self.address, self.handler)  # type: ignore
             self.quit = False
 
         def serve_until_quit(self):
@@ -171,7 +175,7 @@ def _start_server(urlhandler, hostname, port):
             self.server_close()
 
         def server_activate(self):
-            self.base.server_activate(self) # type: ignore
+            self.base.server_activate(self)  # type: ignore
             if self.callback:
                 self.callback(self)
 
@@ -187,10 +191,10 @@ def _start_server(urlhandler, hostname, port):
         def run(self):
             """Start the server."""
             try:
-                DocServer.base = http.server.HTTPServer # type: ignore
-                DocServer.handler = DocHandler # type: ignore
-                DocHandler.MessageClass = email.message.Message # type: ignore
-                DocHandler.urlhandler = staticmethod(self.urlhandler) # type: ignore
+                DocServer.base = http.server.HTTPServer  # type: ignore
+                DocServer.handler = DocHandler  # type: ignore
+                DocHandler.MessageClass = email.message.Message  # type: ignore
+                DocHandler.urlhandler = staticmethod(self.urlhandler)  # type: ignore
                 docsvr = DocServer(self.host, self.port, self.ready)
                 self.docserver = docsvr
                 docsvr.serve_until_quit()
@@ -237,7 +241,7 @@ def start_server():
     """
     global thread
     thread = _start_server(_geetest_urlhandler, "127.0.0.1", 0)
-    print("请打开 " + thread.url + " 进行验证。") # type: ignore
+    print("请打开 " + thread.url + " 进行验证。")  # type: ignore
     return thread
 
 
@@ -246,7 +250,7 @@ def close_server():
     关闭服务器
     """
     global thread
-    thread.stop() # type: ignore
+    thread.stop()  # type: ignore
 
 
 def get_result():
