@@ -8,6 +8,7 @@ from asyncio.exceptions import CancelledError
 from asyncio.tasks import Task, create_task
 import os
 import time
+import random
 
 from .video import Video
 from .utils.aid_bvid_transformer import bvid2aid
@@ -466,8 +467,9 @@ class VideoUploader(AsyncEvent):
                 else Picture().from_file(self.cover_path)
             )
             resp = await _upload_cover(pic, self.credential)
-            self.dispatch(VideoUploaderEvents.AFTER_COVER.value, {"url": resp["url"]})
-            return resp["image_url"]
+            self.dispatch(VideoUploaderEvents.AFTER_COVER.value,
+                          {"url": resp["url"]})
+            return resp["url"]
         except Exception as e:
             self.dispatch(VideoUploaderEvents.COVER_FAILED.value, {"err": e})
             raise e
@@ -537,7 +539,7 @@ class VideoUploader(AsyncEvent):
         # 上传目标 URL
         return (
             "https:"
-            + preupload["endpoint"]
+            + random.choice(preupload["endpoints"])
             + "/"
             + preupload["upos_uri"].removeprefix("upos://")
         )
@@ -904,7 +906,7 @@ class VideoEditor(AsyncEvent):
             )
             resp = await _upload_cover(pic, self.credential)
             self.dispatch(VideoEditorEvents.AFTER_COVER.value, {"url": resp["url"]})
-            self.meta["cover"] = resp["image_url"]
+            self.meta["cover"] = resp["image_url"]  # not sure if this key changed to "url" as well
         except Exception as e:
             self.dispatch(VideoEditorEvents.COVER_FAILED.value, {"err": e})
             raise e
